/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.api.security.impl.ldap;

import org.apache.dolphinscheduler.api.dto.LdapLoginResult;
import org.apache.dolphinscheduler.api.security.impl.AbstractAuthenticator;
import org.apache.dolphinscheduler.dao.entity.User;

import lombok.NonNull;

import org.springframework.beans.factory.annotation.Autowired;

public class LdapAuthenticator extends AbstractAuthenticator {

    @Autowired
    LdapService ldapService;

    @Override
    public User login(@NonNull String userName, String password) {
        User user = null;
        LdapLoginResult ldapLoginResult = ldapService.ldapLogin(userName, password);
        if (ldapLoginResult.isSuccess()) {
            // check if user exist
            user = userService.getUserByUserName(userName);
            if (user == null && ldapService.createIfUserNotExists()) {
                user = userService.createUser(ldapLoginResult.getUserType(), userName, ldapLoginResult.getLdapEmail());
            }
        }
        return user;
    }
}
